==> apollo-mpp-utils-js-3.2.0.jar: apollo-kotlin-apollo-mpp-utils-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'apollo-kotlin-apollo-mpp-utils-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'apollo-kotlin-apollo-mpp-utils-js-legacy'.");
    }root['apollo-kotlin-apollo-mpp-utils-js-legacy'] = factory(typeof this['apollo-kotlin-apollo-mpp-utils-js-legacy'] === 'undefined' ? {} : this['apollo-kotlin-apollo-mpp-utils-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Enum = Kotlin.kotlin.Enum;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var throwISE = Kotlin.throwISE;
  Platform.prototype = Object.create(Enum.prototype);
  Platform.prototype.constructor = Platform;
  function Platform(name, ordinal) {
    Enum.call(this);
    this.name$ = name;
    this.ordinal$ = ordinal;
  }
  function Platform_initFields() {
    Platform_initFields = function () {
    };
    Platform$Jvm_instance = new Platform('Jvm', 0);
    Platform$Native_instance = new Platform('Native', 1);
    Platform$Js_instance = new Platform('Js', 2);
  }
  var Platform$Jvm_instance;
  function Platform$Jvm_getInstance() {
    Platform_initFields();
    return Platform$Jvm_instance;
  }
  var Platform$Native_instance;
  function Platform$Native_getInstance() {
    Platform_initFields();
    return Platform$Native_instance;
  }
  var Platform$Js_instance;
  function Platform$Js_getInstance() {
    Platform_initFields();
    return Platform$Js_instance;
  }
  Platform.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Platform',
    interfaces: [Enum]
  };
  function Platform$values() {
    return [Platform$Jvm_getInstance(), Platform$Native_getInstance(), Platform$Js_getInstance()];
  }
  Platform.values = Platform$values;
  function Platform$valueOf(name) {
    switch (name) {
      case 'Jvm':
        return Platform$Jvm_getInstance();
      case 'Native':
        return Platform$Native_getInstance();
      case 'Js':
        return Platform$Js_getInstance();
      default:throwISE('No enum constant com.apollographql.apollo3.mpp.Platform.' + name);
    }
  }
  Platform.valueOf_61zpoe$ = Platform$valueOf;
  function currentTimeMillis() {
    return Kotlin.Long.fromNumber((new Date()).getTime());
  }
  function currentThreadId() {
    return 'js';
  }
  function ensureNeverFrozen(obj) {
  }
  function isFrozen(obj) {
    return false;
  }
  function freeze(obj) {
  }
  function assertMainThreadOnNative() {
  }
  function platform() {
    return Platform$Js_getInstance();
  }
  Object.defineProperty(Platform, 'Jvm', {
    get: Platform$Jvm_getInstance
  });
  Object.defineProperty(Platform, 'Native', {
    get: Platform$Native_getInstance
  });
  Object.defineProperty(Platform, 'Js', {
    get: Platform$Js_getInstance
  });
  var package$com = _.com || (_.com = {});
  var package$apollographql = package$com.apollographql || (package$com.apollographql = {});
  var package$apollo3 = package$apollographql.apollo3 || (package$apollographql.apollo3 = {});
  var package$mpp = package$apollo3.mpp || (package$apollo3.mpp = {});
  package$mpp.Platform = Platform;
  package$mpp.currentTimeMillis = currentTimeMillis;
  package$mpp.currentThreadId = currentThreadId;
  package$mpp.ensureNeverFrozen_za3rmp$ = ensureNeverFrozen;
  package$mpp.isFrozen_za3rmp$ = isFrozen;
  package$mpp.freeze_za3rmp$ = freeze;
  package$mpp.assertMainThreadOnNative = assertMainThreadOnNative;
  package$mpp.platform = platform;
  Kotlin.defineModule('apollo-kotlin-apollo-mpp-utils-js-legacy', _);
  return _;
}));

//# sourceMappingURL=apollo-kotlin-apollo-mpp-utils-js-legacy.js.map

==> apollo-mpp-utils-js-3.3.0.jar: apollo-kotlin-apollo-mpp-utils-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'apollo-kotlin-apollo-mpp-utils-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'apollo-kotlin-apollo-mpp-utils-js-legacy'.");
    }
    root['apollo-kotlin-apollo-mpp-utils-js-legacy'] = factory(typeof this['apollo-kotlin-apollo-mpp-utils-js-legacy'] === 'undefined' ? {} : this['apollo-kotlin-apollo-mpp-utils-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Enum = Kotlin.kotlin.Enum;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var throwISE = Kotlin.throwISE;
  Platform.prototype = Object.create(Enum.prototype);
  Platform.prototype.constructor = Platform;
  function Platform(name, ordinal) {
    Enum.call(this);
    this.name$ = name;
    this.ordinal$ = ordinal;
  }
  function Platform_initFields() {
    Platform_initFields = function () {
    };
    Platform$Jvm_instance = new Platform('Jvm', 0);
    Platform$Native_instance = new Platform('Native', 1);
    Platform$Js_instance = new Platform('Js', 2);
  }
  var Platform$Jvm_instance;
  function Platform$Jvm_getInstance() {
    Platform_initFields();
    return Platform$Jvm_instance;
  }
  var Platform$Native_instance;
  function Platform$Native_getInstance() {
    Platform_initFields();
    return Platform$Native_instance;
  }
  var Platform$Js_instance;
  function Platform$Js_getInstance() {
    Platform_initFields();
    return Platform$Js_instance;
  }
  Platform.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Platform',
    interfaces: [Enum]
  };
  function Platform$values() {
    return [Platform$Jvm_getInstance(), Platform$Native_getInstance(), Platform$Js_getInstance()];
  }
  Platform.values = Platform$values;
  function Platform$valueOf(name) {
    switch (name) {
      case 'Jvm':
        return Platform$Jvm_getInstance();
      case 'Native':
        return Platform$Native_getInstance();
      case 'Js':
        return Platform$Js_getInstance();
      default:
        throwISE('No enum constant com.apollographql.apollo3.mpp.Platform.' + name);
    }
  }
  Platform.valueOf_61zpoe$ = Platform$valueOf;
  function currentTimeMillis() {
    return Kotlin.Long.fromNumber((new Date()).getTime());
  }
  function currentThreadId() {
    return 'js';
  }
  function ensureNeverFrozen(obj) {
  }
  function isFrozen(obj) {
    return false;
  }
  function freeze(obj) {
  }
  function assertMainThreadOnNative() {
  }
  function platform() {
    return Platform$Js_getInstance();
  }
  Object.defineProperty(Platform, 'Jvm', {
    get: Platform$Jvm_getInstance
  });
  Object.defineProperty(Platform, 'Native', {
    get: Platform$Native_getInstance
  });
  Object.defineProperty(Platform, 'Js', {
    get: Platform$Js_getInstance
  });
  var package$com = _.com || (_.com = {});
  var package$apollographql = package$com.apollographql || (package$com.apollographql = {});
  var package$apollo3 = package$apollographql.apollo3 || (package$apollographql.apollo3 = {});
  var package$mpp = package$apollo3.mpp || (package$apollo3.mpp = {});
  package$mpp.Platform = Platform;
  package$mpp.currentTimeMillis = currentTimeMillis;
  package$mpp.currentThreadId = currentThreadId;
  package$mpp.ensureNeverFrozen_za3rmp$ = ensureNeverFrozen;
  package$mpp.isFrozen_za3rmp$ = isFrozen;
  package$mpp.freeze_za3rmp$ = freeze;
  package$mpp.assertMainThreadOnNative = assertMainThreadOnNative;
  package$mpp.platform = platform;
  Kotlin.defineModule('apollo-kotlin-apollo-mpp-utils-js-legacy', _);
  return _;
}));

//# sourceMappingURL=apollo-kotlin-apollo-mpp-utils-js-legacy.js.map
